package de.mlessmann.certassist;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import de.mlessmann.certassist.openssl.*;
import de.mlessmann.certassist.openssl.CertificateRequest.RequestType;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

class TestOpenSSLCertificateCreator {

    private CertPasswordProvider passwordProvider;

    @BeforeEach
    void setUp() {
        passwordProvider = mock(CertPasswordProvider.class);
        when(passwordProvider.generateNewPassword()).thenReturn("ABC-123");
    }

    @Test
    void testCertificateCreation() throws Exception {
        CertificateProvider certificateProvider = mock(CertificateProvider.class);
        ExecutableResolver executableResolver = new ExecutableResolver();
        var certificateCreator = new OpenSSLCertificateCreator(
            executableResolver,
            passwordProvider,
            certificateProvider
        );

        CertificateRequest certRequest = CertificateRequest
            .builder()
            .commonName("test.home")
            .type(RequestType.STANDALONE_CERTIFICATE)
            .subject(CertificateSubject.builder().country("DE").state("SH").locality("HH").organization("Crazy-Cats"))
            .extension(CertificateRequestExtension.builder().alternativeNames("test2.home", "test3.home"))
            .build();

        try (var cert = certificateCreator.createCertificate(certRequest)) {
            assertThat(certificateCreator.verifyCertificate(cert.getCertificatePath())).isEqualTo(true);
            System.out.println("Certificate created: " + cert);
        }
    }
}
